const type = {};
const types = 'Array Object String Date RegExp Function Boolean Number Error Null Undefined'.split(' ');
/**
 * Check the type of a value.
 */
type.is = (type, val) => Object.prototype.toString.call(val).slice(8, -1) === type;
// Populate helper methods.
types.forEach(t => (type[`is${t}`] = (v) => type.is(t, v)));

/**
 * Return the value or execute as a function
 */
function value(val, ...args) {
    return type.isFunction(val) ? val.apply(this, args) : val;
}

/**
 * Round a number to a given number of decimal places.
 */
function round(val, places = 2) {
    return Number(val.toFixed(places));
}

/**
 * Get the ordinal value for a given number.
 */
function ordinal(num) {
    const suffix = ['th', 'st', 'nd', 'rd'];
    let v = num % 100;
    return num + (suffix[(v - 20) % 10] || suffix[v] || suffix[0]);
}

/**
 * Convert seconds to a human readable time string.
 */
function time(s) {
    const hours = Math.floor(s / 3600);
    const minutes = Math.floor((s % 3600) / 60);
    const seconds = Math.floor((s % 3600) % 60);
    const ms = `0${minutes}`.slice(-2) + ':' + `0${seconds}`.slice(-2);
    return hours === 0 ? ms : `0${hours}`.slice(-2) + ':' + ms;
}

/**
 * Get an item from a given object using string dot notation.
 */
function dot(obj, ref, def = void 0) {
    return ref
        .split('.')
        .reduce((o, i) => (type.isUndefined(o) || !o.hasOwnProperty(i) ? def : o[i]), obj);
}

export { type, value, round, ordinal, time, dot };
//# sourceMappingURL=chitu.es.js.map
