'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var type = {};
var types = 'Array Object String Date RegExp Function Boolean Number Error Null Undefined'.split(' ');
/**
 * Check the type of a value.
 */
type.is = function (type, val) {
    return Object.prototype.toString.call(val).slice(8, -1) === type;
};
// Populate helper methods.
types.forEach(function (t) { return (type["is" + t] = function (v) { return type.is(t, v); }); });

/**
 * Return the value or execute as a function
 */
function value(val) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    return type.isFunction(val) ? val.apply(this, args) : val;
}

/**
 * Round a number to a given number of decimal places.
 */
function round(val, places) {
    if (places === void 0) { places = 2; }
    return Number(val.toFixed(places));
}

/**
 * Get the ordinal value for a given number.
 */
function ordinal(num) {
    var suffix = ['th', 'st', 'nd', 'rd'];
    var v = num % 100;
    return num + (suffix[(v - 20) % 10] || suffix[v] || suffix[0]);
}

/**
 * Convert seconds to a human readable time string.
 */
function time(s) {
    var hours = Math.floor(s / 3600);
    var minutes = Math.floor((s % 3600) / 60);
    var seconds = Math.floor((s % 3600) % 60);
    var ms = ("0" + minutes).slice(-2) + ':' + ("0" + seconds).slice(-2);
    return hours === 0 ? ms : ("0" + hours).slice(-2) + ':' + ms;
}

/**
 * Get an item from a given object using string dot notation.
 */
function dot(obj, ref, def) {
    if (def === void 0) { def = void 0; }
    return ref
        .split('.')
        .reduce(function (o, i) { return (type.isUndefined(o) || !o.hasOwnProperty(i) ? def : o[i]); }, obj);
}

exports.type = type;
exports.value = value;
exports.round = round;
exports.ordinal = ordinal;
exports.time = time;
exports.dot = dot;
//# sourceMappingURL=chitu.js.map
